@@ -15,12 +15,12 @@ require Exporter;
 use Carp;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.00_2';
+$VERSION = '1.00';
 
-use OpenGL(':all');
 @ISA = qw(Exporter);
 
 
+
 =head1 NAME
 
   OpenGL::Image::Common - copyright 2007 Graphcomp - ALL RIGHTS RESERVED
